@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: ghc-mod
 version: 5.5.0.0
-id: ghc-mod-5.5.0.0-9d9cb4ea9f7faebb4d1b0886e204dd67
-key: ghcmo_EkXhaPuMiUFFCEuaTTHufU
+id: ghc-mod-5.5.0.0-685cdf7f391844595dff1ad727107d28
+key: ghcmo_7GkrusqGYS2EHqjDGzH0lV
 license: AGPL-3
 maintainer: Daniel Gröber <dxld@darkboxed.org>
 homepage: http://www.mew.org/~kazu/proj/ghc-mod/
@@ -62,7 +62,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
 data-dir: /usr/share/ghc-mod
-hs-libraries: HSghc-mod-5.5.0.0-EkXhaPuMiUFFCEuaTTHufU
+hs-libraries: HSghc-mod-5.5.0.0-7GkrusqGYS2EHqjDGzH0lV
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
@@ -78,10 +78,10 @@ depends:
     ghc-7.10.3-523035ba1e58dc12893f7ef41f66b61d
     ghc-paths-0.1.0.9-e2ef6e39c0da729a67d19f4c6af9f657
     ghc-syb-utils-0.2.3-e762c220d86bac9001fe97a4dd0b5d58
-    haskell-src-exts-1.17.1-3d12ae784d636e2d6ddab796cfe281a8
-    hlint-1.9.31-c6f35c8d90bdf7dd49a61b0973fa4893
+    haskell-src-exts-1.17.1-22ac2cdd01c70a173d0a3e75bc933334
+    hlint-1.9.32-90db989eb30a130842bd3014d63efdf6
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-journal-0.7.1-739d84421c9ca464fb6d425a63272956
+    monad-journal-0.7.1-9e11141a847c41c0ccebac743a25d261
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
     pipes-4.1.8-48aeb04c3fec70e47e537a12d228def1
@@ -91,7 +91,7 @@ depends:
     split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     temporary-1.2.0.4-82bc44ff7d47fd2873d477b044a2a6ac
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
